@@ -56,6 +56,7 @@ class Insight_Definition:
         widget_id = self.__create_widget(position, widget_type)
         if(query_ids!=[]):
             self.edit_widget(widget_id, widget_type,query_ids, settings, texts, charts)
+        logging.info("Widget created")
         return widget_id
 
     def edit_widget(self, widget_id, widget_type: str, query_ids:list, field_codes:dict, texts:dict={}, charts:list=[]):
@@ -78,7 +79,6 @@ class Insight_Definition:
                             settings[field + "_id"] = column["id"]
                             break
 
-        logging.info("SETTINGS {}".format(settings))
         body = {
             "id" : widget_id,
             "type": "widget",
@@ -120,7 +120,7 @@ class Insight_Definition:
             "Content-Type": "application/json",
             "Authorization": "Bearer" + " " + self._token
         }
-        logging.info("URL {}".format(url))
+        #logging.info("URL {}".format(url))
         r = s.post(url=url, json=body, headers=headers)
         r.raise_for_status()
         return r.json()
@@ -139,7 +139,7 @@ class Insight_Definition:
             "Authorization": "Bearer" + " " + self._token
         }
         query_url = self.smart_insight_url + '/definitions/' + self.definition_id + '/components/'
-        logging.info("URL {}".format(query_url))
+        #logging.info("URL {}".format(query_url))
         r = s.post(url=query_url, json=body, headers=headers)
         r.raise_for_status()
         print(r.json())
@@ -161,7 +161,7 @@ class Insight_Definition:
             "Authorization": "Bearer" + " " + self._token
         }
         query_url = self.smart_insight_url + '/definitions/' + self.definition_id + '/components/'
-        logging.info("URL {}".format(query_url))
+        #logging.info("URL {}".format(query_url))
         r = s.post(url=query_url, json=body, headers=headers)
         r.raise_for_status()
         print(r.json())
@@ -250,7 +250,7 @@ class Insight_Definition:
             "Authorization": "Bearer" + " " + self._token
         }
         query_url = self.smart_insight_url + '/definitions/' + self.definition_id + '/components/'
-        logging.info("URL {}".format(query_url))
+        #logging.info("URL {}".format(query_url))
         r = s.post(url=query_url, json=body, headers=headers)
         r.raise_for_status()
         print(r.json())
@@ -328,7 +328,7 @@ class Insight_Definition:
             "queryComponent":False
         }
 
-        logging.info("URL: {}".format(url))
+        #logging.info("URL: {}".format(url))
 
         s = requests.Session()
         s.keep_alive = False
@@ -356,7 +356,7 @@ class Insight_Definition:
 
         body = df.to_json(orient="table", index=index)
         url = self.smart_insight_url+"/definitions/"+self.definition_id+"/data_queries/"+data_id+"/data"
-        logging.info("URL: {}".format(url))
+        #logging.info("URL: {}".format(url))
         s = requests.Session()
         s.keep_alive = False
         retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
@@ -373,7 +373,7 @@ class Insight_Definition:
 
     def load_data_entities(self, data_id):
         url = self.smart_insight_url+"/definitions/"+self.definition_id+"/queries"
-        logging.info("URL {}".format(url))
+        #logging.info("URL {}".format(url))
         s = requests.Session()
         s.keep_alive = False
         retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
@@ -412,7 +412,7 @@ class Insight_Definition:
         body = {
             "name": component_name
         }
-        logging.info("URL: {}".format(url))
+        #logging.info("URL: {}".format(url))
 
         s = requests.Session()
         s.keep_alive = False
@@ -448,7 +448,7 @@ class Insight_Definition:
             "link":cta_url
         }
 
-        logging.info("URL: {}".format(url))
+        #logging.info("URL: {}".format(url))
 
         s = requests.Session()
         s.keep_alive = False
@@ -494,7 +494,7 @@ class Insight_Definition:
             "secondItemEnabled": second_item_enabled,
             "formatterType":formatter_type
         }
-        logging.info("URL: {}".format(url))
+        #logging.info("URL: {}".format(url))
 
         s = requests.Session()
         s.keep_alive = False
@@ -532,7 +532,7 @@ class Insight_Definition:
             "valid": True
         }
 
-        logging.info("URL: {}".format(url))
+        #logging.info("URL: {}".format(url))
 
         s = requests.Session()
         s.keep_alive = False
@@ -625,7 +625,7 @@ class Insight_Definition:
         s.mount('https://', HTTPAdapter(max_retries=retries))
 
         authentication_url = self._base_url_askdata + '/smartdataset/datasets/slug/' + self.agent_id + '/' + dataset_slug
-        logging.info("AUTH URL {}".format(authentication_url))
+        #logging.info("AUTH URL {}".format(authentication_url))
 
         headers = {"Authorization": "Bearer" + " " + self._token}
         response = s.get(url=authentication_url, headers=headers)
@@ -821,7 +821,7 @@ class Insight_Definition:
         }
         query_url = self.smart_insight_url +'/definitions/'+ self.definition_id +'/nl_queries/'+ query_id + '/nl'
 
-        logging.info("QUERY URL {}".format(query_url))
+        #logging.info("QUERY URL {}".format(query_url))
         r = s.put(url=query_url, json=body_query, headers=headers)
 
         self.components = r.json()["components"]
@@ -843,7 +843,7 @@ class Insight_Definition:
             "Authorization": "Bearer" + " " + self._token
         }
         query_url = self.smart_insight_url + '/definitions/' + self.definition_id + '/components/'
-        logging.info("URL {}".format(query_url))
+        #logging.info("URL {}".format(query_url))
         r = s.post(url=query_url, json=body, headers=headers)
         r.raise_for_status()
         print(r.json())
@@ -912,7 +912,7 @@ class Insight_Definition:
                 "Authorization": "Bearer" + " " + self._token
             }
             query_url = self.smart_insight_url + '/definitions/' + self.definition_id + '/components/'
-            logging.info("URL {}".format(query_url))
+            #logging.info("URL {}".format(query_url))
             r = s.post(url=url, json=body, headers=headers)
             r.raise_for_status()
         else:
@@ -953,7 +953,7 @@ class Insight_Definition:
                 "Authorization": "Bearer" + " " + self._token
             }
             query_url = self.smart_insight_url + '/definitions/' + self.definition_id + '/components/'
-            logging.info("URL {}".format(query_url))
+            #logging.info("URL {}".format(query_url))
             r = s.post(url=url, json=body, headers=headers)
             r.raise_for_status()
         else:
@@ -1031,7 +1031,7 @@ class Insight_Definition:
             "Authorization": "Bearer" + " " + self._token
         }
         query_url = self.smart_insight_url + '/definitions/' + self.definition_id + '/components/'+component_id
-        logging.info("URL {}".format(query_url))
+        #logging.info("URL {}".format(query_url))
         r = s.delete(url=query_url, headers=headers)
         r.raise_for_status()
 
