@@ -64,9 +64,11 @@ class TimePeriodOperator(Enum):
 class CTDOperator(Enum):
     CURR = auto()
     PREV = auto()
-    PREV_BFR = auto()
+    PREV_CURR = auto()
+    START_PREV = auto()
     NEXT = auto()
-    NEXT_AFT = auto()
+    NEXT_END = auto()
+    CURR_NEXT = auto()
     BFR = auto()
     AFT = auto()
 
